import * as pulumi from "@pulumi/pulumi";
/**
 * The ``AWS::ApiGateway::GatewayResponse`` resource creates a gateway response for your API. For more information, see [API Gateway Responses](https://docs.aws.amazon.com/apigateway/latest/developerguide/customize-gateway-responses.html#api-gateway-gatewayResponse-definition) in the *API Gateway Developer Guide*.
 */
export declare class GatewayResponse extends pulumi.CustomResource {
    /**
     * Get an existing GatewayResponse resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): GatewayResponse;
    /**
     * Returns true if the given object is an instance of GatewayResponse.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is GatewayResponse;
    /**
     * The ID for the gateway response. For example: `abc123` .
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * Response parameters (paths, query strings and headers) of the GatewayResponse as a string-to-string map of key-value pairs.
     */
    readonly responseParameters: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Response templates of the GatewayResponse as a string-to-string map of key-value pairs.
     */
    readonly responseTemplates: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * The response type of the associated GatewayResponse.
     */
    readonly responseType: pulumi.Output<string>;
    /**
     * The string identifier of the associated RestApi.
     */
    readonly restApiId: pulumi.Output<string>;
    /**
     * The HTTP status code for this GatewayResponse.
     */
    readonly statusCode: pulumi.Output<string | undefined>;
    /**
     * Create a GatewayResponse resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: GatewayResponseArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a GatewayResponse resource.
 */
export interface GatewayResponseArgs {
    /**
     * Response parameters (paths, query strings and headers) of the GatewayResponse as a string-to-string map of key-value pairs.
     */
    responseParameters?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * Response templates of the GatewayResponse as a string-to-string map of key-value pairs.
     */
    responseTemplates?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The response type of the associated GatewayResponse.
     */
    responseType: pulumi.Input<string>;
    /**
     * The string identifier of the associated RestApi.
     */
    restApiId: pulumi.Input<string>;
    /**
     * The HTTP status code for this GatewayResponse.
     */
    statusCode?: pulumi.Input<string>;
}
