import * as pulumi from "@pulumi/pulumi";
/**
 * The ``AWS::ApiGateway::Model`` resource defines the structure of a request or response payload for an API method.
 */
export declare function getModel(args: GetModelArgs, opts?: pulumi.InvokeOptions): Promise<GetModelResult>;
export interface GetModelArgs {
    /**
     * A name for the model. If you don't specify a name, CFN generates a unique physical ID and uses that ID for the model name. For more information, see [Name Type](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-name.html).
     *   If you specify a name, you cannot perform updates that require replacement of this resource. You can perform updates that require no or some interruption. If you must replace the resource, specify a new name.
     */
    name: string;
    /**
     * The string identifier of the associated RestApi.
     */
    restApiId: string;
}
export interface GetModelResult {
    /**
     * The description of the model.
     */
    readonly description?: string;
    /**
     * The schema for the model. For `application/json` models, this should be JSON schema draft 4 model. Do not include "\*&#47;" characters in the description of any properties because such "\*&#47;" characters may be interpreted as the closing marker for comments in some languages, such as Java or JavaScript, causing the installation of your API's SDK generated by API Gateway to fail.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::ApiGateway::Model` for more information about the expected schema for this property.
     */
    readonly schema?: any;
}
/**
 * The ``AWS::ApiGateway::Model`` resource defines the structure of a request or response payload for an API method.
 */
export declare function getModelOutput(args: GetModelOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetModelResult>;
export interface GetModelOutputArgs {
    /**
     * A name for the model. If you don't specify a name, CFN generates a unique physical ID and uses that ID for the model name. For more information, see [Name Type](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-name.html).
     *   If you specify a name, you cannot perform updates that require replacement of this resource. You can perform updates that require no or some interruption. If you must replace the resource, specify a new name.
     */
    name: pulumi.Input<string>;
    /**
     * The string identifier of the associated RestApi.
     */
    restApiId: pulumi.Input<string>;
}
