import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The ``AWS::ApiGateway::VpcLink`` resource creates an API Gateway VPC link for a REST API to access resources in an Amazon Virtual Private Cloud (VPC). For more information, see [vpclink:create](https://docs.aws.amazon.com/apigateway/latest/api/API_CreateVpcLink.html) in the ``Amazon API Gateway REST API Reference``.
 */
export declare function getVpcLink(args: GetVpcLinkArgs, opts?: pulumi.InvokeOptions): Promise<GetVpcLinkResult>;
export interface GetVpcLinkArgs {
    /**
     * The ID for the VPC link. For example: `abc123` .
     */
    vpcLinkId: string;
}
export interface GetVpcLinkResult {
    /**
     * The description of the VPC link.
     */
    readonly description?: string;
    /**
     * The name used to label and identify the VPC link.
     */
    readonly name?: string;
    /**
     * An array of arbitrary tags (key-value pairs) to associate with the VPC link.
     */
    readonly tags?: outputs.Tag[];
    /**
     * The ID for the VPC link. For example: `abc123` .
     */
    readonly vpcLinkId?: string;
}
/**
 * The ``AWS::ApiGateway::VpcLink`` resource creates an API Gateway VPC link for a REST API to access resources in an Amazon Virtual Private Cloud (VPC). For more information, see [vpclink:create](https://docs.aws.amazon.com/apigateway/latest/api/API_CreateVpcLink.html) in the ``Amazon API Gateway REST API Reference``.
 */
export declare function getVpcLinkOutput(args: GetVpcLinkOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetVpcLinkResult>;
export interface GetVpcLinkOutputArgs {
    /**
     * The ID for the VPC link. For example: `abc123` .
     */
    vpcLinkId: pulumi.Input<string>;
}
