import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::AppConfig::Deployment
 */
export declare class Deployment extends pulumi.CustomResource {
    /**
     * Get an existing Deployment resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Deployment;
    /**
     * Returns true if the given object is an instance of Deployment.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Deployment;
    /**
     * The application ID.
     */
    readonly applicationId: pulumi.Output<string>;
    /**
     * The configuration profile ID.
     */
    readonly configurationProfileId: pulumi.Output<string>;
    /**
     * The configuration version to deploy. If deploying an AWS AppConfig hosted configuration version, you can specify either the version number or version label. For all other configurations, you must specify the version number.
     */
    readonly configurationVersion: pulumi.Output<string>;
    /**
     * The sequence number of the deployment.
     */
    readonly deploymentNumber: pulumi.Output<string>;
    /**
     * The deployment strategy ID.
     */
    readonly deploymentStrategyId: pulumi.Output<string>;
    /**
     * A description of the deployment.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * A map of dynamic extension parameter names to values to pass to associated extensions with `PRE_START_DEPLOYMENT` actions.
     */
    readonly dynamicExtensionParameters: pulumi.Output<outputs.appconfig.DeploymentDynamicExtensionParameters[] | undefined>;
    /**
     * The environment ID.
     */
    readonly environmentId: pulumi.Output<string>;
    /**
     * The AWS Key Management Service key identifier (key ID, key alias, or key ARN) provided when the resource was created or updated.
     */
    readonly kmsKeyIdentifier: pulumi.Output<string | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.CreateOnlyTag[] | undefined>;
    /**
     * Create a Deployment resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DeploymentArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Deployment resource.
 */
export interface DeploymentArgs {
    /**
     * The application ID.
     */
    applicationId: pulumi.Input<string>;
    /**
     * The configuration profile ID.
     */
    configurationProfileId: pulumi.Input<string>;
    /**
     * The configuration version to deploy. If deploying an AWS AppConfig hosted configuration version, you can specify either the version number or version label. For all other configurations, you must specify the version number.
     */
    configurationVersion: pulumi.Input<string>;
    /**
     * The deployment strategy ID.
     */
    deploymentStrategyId: pulumi.Input<string>;
    /**
     * A description of the deployment.
     */
    description?: pulumi.Input<string>;
    /**
     * A map of dynamic extension parameter names to values to pass to associated extensions with `PRE_START_DEPLOYMENT` actions.
     */
    dynamicExtensionParameters?: pulumi.Input<pulumi.Input<inputs.appconfig.DeploymentDynamicExtensionParametersArgs>[]>;
    /**
     * The environment ID.
     */
    environmentId: pulumi.Input<string>;
    /**
     * The AWS Key Management Service key identifier (key ID, key alias, or key ARN) provided when the resource was created or updated.
     */
    kmsKeyIdentifier?: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.CreateOnlyTagArgs>[]>;
}
