import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::AppIntegrations::DataIntegration
 */
export declare function getDataIntegration(args: GetDataIntegrationArgs, opts?: pulumi.InvokeOptions): Promise<GetDataIntegrationResult>;
export interface GetDataIntegrationArgs {
    /**
     * The unique identifer of the data integration.
     */
    id: string;
}
export interface GetDataIntegrationResult {
    /**
     * The Amazon Resource Name (ARN) of the data integration.
     */
    readonly dataIntegrationArn?: string;
    /**
     * The data integration description.
     */
    readonly description?: string;
    /**
     * The configuration for what files should be pulled from the source.
     */
    readonly fileConfiguration?: outputs.appintegrations.DataIntegrationFileConfiguration;
    /**
     * The unique identifer of the data integration.
     */
    readonly id?: string;
    /**
     * The name of the data integration.
     */
    readonly name?: string;
    /**
     * The configuration for what data should be pulled from the source.
     */
    readonly objectConfiguration?: {
        [key: string]: any;
    };
    /**
     * The tags (keys and values) associated with the data integration.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource Type definition for AWS::AppIntegrations::DataIntegration
 */
export declare function getDataIntegrationOutput(args: GetDataIntegrationOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDataIntegrationResult>;
export interface GetDataIntegrationOutputArgs {
    /**
     * The unique identifer of the data integration.
     */
    id: pulumi.Input<string>;
}
