import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * The AWS::AppRunner::Service resource specifies an AppRunner Service.
 */
export declare class Service extends pulumi.CustomResource {
    /**
     * Get an existing Service resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Service;
    /**
     * Returns true if the given object is an instance of Service.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Service;
    /**
     * Autoscaling configuration ARN
     */
    readonly autoScalingConfigurationArn: pulumi.Output<string | undefined>;
    /**
     * An optional custom encryption key that App Runner uses to encrypt the copy of your source repository that it maintains and your service logs. By default, App Runner uses an AWS managed key .
     */
    readonly encryptionConfiguration: pulumi.Output<outputs.apprunner.ServiceEncryptionConfiguration | undefined>;
    /**
     * The settings for the health check that AWS App Runner performs to monitor the health of the App Runner service.
     */
    readonly healthCheckConfiguration: pulumi.Output<outputs.apprunner.ServiceHealthCheckConfiguration | undefined>;
    /**
     * The runtime configuration of instances (scaling units) of your service.
     */
    readonly instanceConfiguration: pulumi.Output<outputs.apprunner.ServiceInstanceConfiguration | undefined>;
    /**
     * Configuration settings related to network traffic of the web application that the App Runner service runs.
     */
    readonly networkConfiguration: pulumi.Output<outputs.apprunner.ServiceNetworkConfiguration | undefined>;
    /**
     * The observability configuration of your service.
     */
    readonly observabilityConfiguration: pulumi.Output<outputs.apprunner.ServiceObservabilityConfiguration | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the AppRunner Service.
     */
    readonly serviceArn: pulumi.Output<string>;
    /**
     * The AppRunner Service Id
     */
    readonly serviceId: pulumi.Output<string>;
    /**
     * The AppRunner Service Name.
     */
    readonly serviceName: pulumi.Output<string | undefined>;
    /**
     * The Service Url of the AppRunner Service.
     */
    readonly serviceUrl: pulumi.Output<string>;
    /**
     * The source to deploy to the App Runner service. It can be a code or an image repository.
     */
    readonly sourceConfiguration: pulumi.Output<outputs.apprunner.ServiceSourceConfiguration>;
    /**
     * AppRunner Service status.
     */
    readonly status: pulumi.Output<string>;
    /**
     * An optional list of metadata items that you can associate with the App Runner service resource. A tag is a key-value pair.
     */
    readonly tags: pulumi.Output<outputs.CreateOnlyTag[] | undefined>;
    /**
     * Create a Service resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ServiceArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Service resource.
 */
export interface ServiceArgs {
    /**
     * Autoscaling configuration ARN
     */
    autoScalingConfigurationArn?: pulumi.Input<string>;
    /**
     * An optional custom encryption key that App Runner uses to encrypt the copy of your source repository that it maintains and your service logs. By default, App Runner uses an AWS managed key .
     */
    encryptionConfiguration?: pulumi.Input<inputs.apprunner.ServiceEncryptionConfigurationArgs>;
    /**
     * The settings for the health check that AWS App Runner performs to monitor the health of the App Runner service.
     */
    healthCheckConfiguration?: pulumi.Input<inputs.apprunner.ServiceHealthCheckConfigurationArgs>;
    /**
     * The runtime configuration of instances (scaling units) of your service.
     */
    instanceConfiguration?: pulumi.Input<inputs.apprunner.ServiceInstanceConfigurationArgs>;
    /**
     * Configuration settings related to network traffic of the web application that the App Runner service runs.
     */
    networkConfiguration?: pulumi.Input<inputs.apprunner.ServiceNetworkConfigurationArgs>;
    /**
     * The observability configuration of your service.
     */
    observabilityConfiguration?: pulumi.Input<inputs.apprunner.ServiceObservabilityConfigurationArgs>;
    /**
     * The AppRunner Service Name.
     */
    serviceName?: pulumi.Input<string>;
    /**
     * The source to deploy to the App Runner service. It can be a code or an image repository.
     */
    sourceConfiguration: pulumi.Input<inputs.apprunner.ServiceSourceConfigurationArgs>;
    /**
     * An optional list of metadata items that you can associate with the App Runner service resource. A tag is a key-value pair.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.CreateOnlyTagArgs>[]>;
}
