import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Represents a stored analysis within a collaboration
 */
export declare class AnalysisTemplate extends pulumi.CustomResource {
    /**
     * Get an existing AnalysisTemplate resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): AnalysisTemplate;
    /**
     * Returns true if the given object is an instance of AnalysisTemplate.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AnalysisTemplate;
    /**
     * The member who can query can provide this placeholder for a literal data value in an analysis template
     */
    readonly analysisParameters: pulumi.Output<outputs.cleanrooms.AnalysisTemplateAnalysisParameter[] | undefined>;
    /**
     * Returns the identifier for the analysis template.
     *
     * Example: `a1b2c3d4-5678-90ab-cdef-EXAMPLE2222`
     */
    readonly analysisTemplateIdentifier: pulumi.Output<string>;
    /**
     * Returns the Amazon Resource Name (ARN) of the analysis template.
     *
     * Example: `arn:aws:cleanrooms:us-east-1:111122223333:membership/a1b2c3d4-5678-90ab-cdef-EXAMPLE11111/analysistemplates/a1b2c3d4-5678-90ab-cdef-EXAMPLE2222`
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Returns the unique ARN for the analysis template’s associated collaboration.
     *
     * Example: `arn:aws:cleanrooms:us-east-1:111122223333:collaboration/a1b2c3d4-5678-90ab-cdef-EXAMPLE33333`
     */
    readonly collaborationArn: pulumi.Output<string>;
    /**
     * Returns the unique ID for the associated collaboration of the analysis template.
     *
     * Example: `a1b2c3d4-5678-90ab-cdef-EXAMPLE33333`
     */
    readonly collaborationIdentifier: pulumi.Output<string>;
    /**
     * The description of the analysis template.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The format of the analysis template.
     */
    readonly format: pulumi.Output<enums.cleanrooms.AnalysisTemplateFormat>;
    /**
     * Returns the Amazon Resource Name (ARN) of the member who created the analysis template.
     *
     * Example: `arn:aws:cleanrooms:us-east-1:111122223333:membership/a1b2c3d4-5678-90ab-cdef-EXAMPLE11111`
     */
    readonly membershipArn: pulumi.Output<string>;
    /**
     * The identifier for a membership resource.
     */
    readonly membershipIdentifier: pulumi.Output<string>;
    /**
     * The name of the analysis template.
     */
    readonly name: pulumi.Output<string>;
    readonly schema: pulumi.Output<outputs.cleanrooms.AnalysisTemplateAnalysisSchema>;
    /**
     * The source of the analysis template.
     */
    readonly source: pulumi.Output<outputs.cleanrooms.AnalysisTemplateAnalysisSource>;
    /**
     * An arbitrary set of tags (key-value pairs) for this cleanrooms analysis template.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a AnalysisTemplate resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AnalysisTemplateArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a AnalysisTemplate resource.
 */
export interface AnalysisTemplateArgs {
    /**
     * The member who can query can provide this placeholder for a literal data value in an analysis template
     */
    analysisParameters?: pulumi.Input<pulumi.Input<inputs.cleanrooms.AnalysisTemplateAnalysisParameterArgs>[]>;
    /**
     * The description of the analysis template.
     */
    description?: pulumi.Input<string>;
    /**
     * The format of the analysis template.
     */
    format: pulumi.Input<enums.cleanrooms.AnalysisTemplateFormat>;
    /**
     * The identifier for a membership resource.
     */
    membershipIdentifier: pulumi.Input<string>;
    /**
     * The name of the analysis template.
     */
    name?: pulumi.Input<string>;
    /**
     * The source of the analysis template.
     */
    source: pulumi.Input<inputs.cleanrooms.AnalysisTemplateAnalysisSourceArgs>;
    /**
     * An arbitrary set of tags (key-value pairs) for this cleanrooms analysis template.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
