import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Represents a table that can be associated with collaborations
 */
export declare class ConfiguredTable extends pulumi.CustomResource {
    /**
     * Get an existing ConfiguredTable resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ConfiguredTable;
    /**
     * Returns true if the given object is an instance of ConfiguredTable.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ConfiguredTable;
    /**
     * The columns within the underlying AWS Glue table that can be utilized within collaborations.
     */
    readonly allowedColumns: pulumi.Output<string[]>;
    /**
     * The analysis method for the configured table.
     *
     * `DIRECT_QUERY` allows SQL queries to be run directly on this table.
     *
     * `DIRECT_JOB` allows PySpark jobs to be run directly on this table.
     *
     * `MULTIPLE` allows both SQL queries and PySpark jobs to be run directly on this table.
     */
    readonly analysisMethod: pulumi.Output<enums.cleanrooms.ConfiguredTableAnalysisMethod>;
    /**
     * The analysis rule that was created for the configured table.
     */
    readonly analysisRules: pulumi.Output<outputs.cleanrooms.ConfiguredTableAnalysisRule[] | undefined>;
    /**
     * Returns the Amazon Resource Name (ARN) of the specified configured table.
     *
     * Example: `arn:aws:cleanrooms:us-east-1:111122223333:configuredtable/a1b2c3d4-5678-90ab-cdef-EXAMPLE11111`
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Returns the unique identifier of the specified configured table.
     *
     * Example: `a1b2c3d4-5678-90ab-cdef-EXAMPLE33333`
     */
    readonly configuredTableIdentifier: pulumi.Output<string>;
    /**
     * A description for the configured table.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * A name for the configured table.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The table that this configured table represents.
     */
    readonly tableReference: pulumi.Output<outputs.cleanrooms.ConfiguredTableTableReference0Properties | outputs.cleanrooms.ConfiguredTableTableReference1Properties | outputs.cleanrooms.ConfiguredTableTableReference2Properties>;
    /**
     * An arbitrary set of tags (key-value pairs) for this cleanrooms collaboration.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a ConfiguredTable resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ConfiguredTableArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ConfiguredTable resource.
 */
export interface ConfiguredTableArgs {
    /**
     * The columns within the underlying AWS Glue table that can be utilized within collaborations.
     */
    allowedColumns: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The analysis method for the configured table.
     *
     * `DIRECT_QUERY` allows SQL queries to be run directly on this table.
     *
     * `DIRECT_JOB` allows PySpark jobs to be run directly on this table.
     *
     * `MULTIPLE` allows both SQL queries and PySpark jobs to be run directly on this table.
     */
    analysisMethod: pulumi.Input<enums.cleanrooms.ConfiguredTableAnalysisMethod>;
    /**
     * The analysis rule that was created for the configured table.
     */
    analysisRules?: pulumi.Input<pulumi.Input<inputs.cleanrooms.ConfiguredTableAnalysisRuleArgs>[]>;
    /**
     * A description for the configured table.
     */
    description?: pulumi.Input<string>;
    /**
     * A name for the configured table.
     */
    name?: pulumi.Input<string>;
    /**
     * The table that this configured table represents.
     */
    tableReference: pulumi.Input<inputs.cleanrooms.ConfiguredTableTableReference0PropertiesArgs | inputs.cleanrooms.ConfiguredTableTableReference1PropertiesArgs | inputs.cleanrooms.ConfiguredTableTableReference2PropertiesArgs>;
    /**
     * An arbitrary set of tags (key-value pairs) for this cleanrooms collaboration.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
