import * as pulumi from "@pulumi/pulumi";
/**
 * The default version of a resource that has been registered in the CloudFormation Registry.
 */
export declare function getResourceDefaultVersion(args: GetResourceDefaultVersionArgs, opts?: pulumi.InvokeOptions): Promise<GetResourceDefaultVersionResult>;
export interface GetResourceDefaultVersionArgs {
    /**
     * The Amazon Resource Name (ARN) of the type. This is used to uniquely identify a ResourceDefaultVersion
     */
    arn: string;
}
export interface GetResourceDefaultVersionResult {
    /**
     * The Amazon Resource Name (ARN) of the type. This is used to uniquely identify a ResourceDefaultVersion
     */
    readonly arn?: string;
    /**
     * The name of the type being registered.
     *
     * We recommend that type names adhere to the following pattern: company_or_organization::service::type.
     */
    readonly typeName?: string;
    /**
     * The Amazon Resource Name (ARN) of the type version.
     */
    readonly typeVersionArn?: string;
    /**
     * The ID of an existing version of the resource to set as the default.
     */
    readonly versionId?: string;
}
/**
 * The default version of a resource that has been registered in the CloudFormation Registry.
 */
export declare function getResourceDefaultVersionOutput(args: GetResourceDefaultVersionOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetResourceDefaultVersionResult>;
export interface GetResourceDefaultVersionOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the type. This is used to uniquely identify a ResourceDefaultVersion
     */
    arn: pulumi.Input<string>;
}
