import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * Specifies the configuration data for a registered hook in CloudFormation Registry.
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const hookTypeConfig = new aws_native.cloudformation.HookTypeConfig("hookTypeConfig", {
 *     typeName: "My::Sample::Hook",
 *     configuration: "{\"CloudFormationConfiguration\":{\"HookConfiguration\":{\"TargetStacks\":\"ALL\",\"FailureMode\":\"WARN\",\"Properties\":{\"limitSize\": \"1\",\"encryptionAlgorithm\": \"aws:kms\"}}}}",
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const hookTypeConfig = new aws_native.cloudformation.HookTypeConfig("hookTypeConfig", {
 *     typeName: "My::Sample::Hook",
 *     configuration: "{\"CloudFormationConfiguration\":{\"HookConfiguration\":{\"TargetStacks\":\"ALL\",\"FailureMode\":\"WARN\",\"Properties\":{\"limitSize\": \"1\",\"encryptionAlgorithm\": \"aws:kms\"}}}}",
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const hookTypeConfig = new aws_native.cloudformation.HookTypeConfig("hookTypeConfig", {
 *     typeArn: "arn:aws:cloudformation:us-west-2:123456789012:type/hook/My-Sample-Hook",
 *     configuration: "{\"CloudFormationConfiguration\":{\"HookConfiguration\":{\"TargetStacks\":\"ALL\",\"FailureMode\":\"WARN\",\"Properties\":{\"limitSize\": \"1\",\"encryptionAlgorithm\": \"aws:kms\"}}}}",
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const hookTypeConfig = new aws_native.cloudformation.HookTypeConfig("hookTypeConfig", {
 *     typeArn: "arn:aws:cloudformation:us-west-2:123456789012:type/hook/My-Sample-Hook",
 *     configuration: "{\"CloudFormationConfiguration\":{\"HookConfiguration\":{\"TargetStacks\":\"ALL\",\"FailureMode\":\"WARN\",\"Properties\":{\"limitSize\": \"1\",\"encryptionAlgorithm\": \"aws:kms\"}}}}",
 * });
 *
 * ```
 */
export declare class HookTypeConfig extends pulumi.CustomResource {
    /**
     * Get an existing HookTypeConfig resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): HookTypeConfig;
    /**
     * Returns true if the given object is an instance of HookTypeConfig.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is HookTypeConfig;
    /**
     * The configuration data for the extension, in this account and region.
     */
    readonly configuration: pulumi.Output<string | undefined>;
    /**
     * An alias by which to refer to this extension configuration data.
     */
    readonly configurationAlias: pulumi.Output<enums.cloudformation.HookTypeConfigConfigurationAlias | undefined>;
    /**
     * The Amazon Resource Name (ARN) for the configuration data, in this account and region.
     */
    readonly configurationArn: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the type without version number.
     */
    readonly typeArn: pulumi.Output<string | undefined>;
    /**
     * The name of the type being registered.
     *
     * We recommend that type names adhere to the following pattern: company_or_organization::service::type.
     */
    readonly typeName: pulumi.Output<string | undefined>;
    /**
     * Create a HookTypeConfig resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: HookTypeConfigArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a HookTypeConfig resource.
 */
export interface HookTypeConfigArgs {
    /**
     * The configuration data for the extension, in this account and region.
     */
    configuration?: pulumi.Input<string>;
    /**
     * An alias by which to refer to this extension configuration data.
     */
    configurationAlias?: pulumi.Input<enums.cloudformation.HookTypeConfigConfigurationAlias>;
    /**
     * The Amazon Resource Name (ARN) of the type without version number.
     */
    typeArn?: pulumi.Input<string>;
    /**
     * The name of the type being registered.
     *
     * We recommend that type names adhere to the following pattern: company_or_organization::service::type.
     */
    typeName?: pulumi.Input<string>;
}
