import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * A cache policy.
 *  When it's attached to a cache behavior, the cache policy determines the following:
 *   +  The values that CloudFront includes in the cache key. These values can include HTTP headers, cookies, and URL query strings. CloudFront uses the cache key to find an object in its cache that it can return to the viewer.
 *   +  The default, minimum, and maximum time to live (TTL) values that you want objects to stay in the CloudFront cache.
 *
 *  The headers, cookies, and query strings that are included in the cache key are also included in requests that CloudFront sends to the origin. CloudFront sends a request when it can't find a valid object in its cache that matches the request's cache key. If you want to send values to the origin but *not* include them in the cache key, use ``OriginRequestPolicy``.
 */
export declare function getCachePolicy(args: GetCachePolicyArgs, opts?: pulumi.InvokeOptions): Promise<GetCachePolicyResult>;
export interface GetCachePolicyArgs {
    /**
     * The unique identifier for the cache policy. For example: `2766f7b2-75c5-41c6-8f06-bf4303a2f2f5` .
     */
    id: string;
}
export interface GetCachePolicyResult {
    /**
     * The cache policy configuration.
     */
    readonly cachePolicyConfig?: outputs.cloudfront.CachePolicyConfig;
    /**
     * The unique identifier for the cache policy. For example: `2766f7b2-75c5-41c6-8f06-bf4303a2f2f5` .
     */
    readonly id?: string;
    /**
     * The date and time when the cache policy was last modified.
     */
    readonly lastModifiedTime?: string;
}
/**
 * A cache policy.
 *  When it's attached to a cache behavior, the cache policy determines the following:
 *   +  The values that CloudFront includes in the cache key. These values can include HTTP headers, cookies, and URL query strings. CloudFront uses the cache key to find an object in its cache that it can return to the viewer.
 *   +  The default, minimum, and maximum time to live (TTL) values that you want objects to stay in the CloudFront cache.
 *
 *  The headers, cookies, and query strings that are included in the cache key are also included in requests that CloudFront sends to the origin. CloudFront sends a request when it can't find a valid object in its cache that matches the request's cache key. If you want to send values to the origin but *not* include them in the cache key, use ``OriginRequestPolicy``.
 */
export declare function getCachePolicyOutput(args: GetCachePolicyOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetCachePolicyResult>;
export interface GetCachePolicyOutputArgs {
    /**
     * The unique identifier for the cache policy. For example: `2766f7b2-75c5-41c6-8f06-bf4303a2f2f5` .
     */
    id: pulumi.Input<string>;
}
