import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The resource schema to create a CodeArtifact repository.
 */
export declare function getRepository(args: GetRepositoryArgs, opts?: pulumi.InvokeOptions): Promise<GetRepositoryResult>;
export interface GetRepositoryArgs {
    /**
     * The ARN of the repository.
     */
    arn: string;
}
export interface GetRepositoryResult {
    /**
     * The ARN of the repository.
     */
    readonly arn?: string;
    /**
     * A text description of the repository.
     */
    readonly description?: string;
    /**
     * A list of external connections associated with the repository.
     */
    readonly externalConnections?: string[];
    /**
     * The name of the repository. This is used for GetAtt
     */
    readonly name?: string;
    /**
     * The access control resource policy on the provided repository.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::CodeArtifact::Repository` for more information about the expected schema for this property.
     */
    readonly permissionsPolicyDocument?: any;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
    /**
     * A list of upstream repositories associated with the repository.
     */
    readonly upstreams?: string[];
}
/**
 * The resource schema to create a CodeArtifact repository.
 */
export declare function getRepositoryOutput(args: GetRepositoryOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetRepositoryResult>;
export interface GetRepositoryOutputArgs {
    /**
     * The ARN of the repository.
     */
    arn: pulumi.Input<string>;
}
