import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::Connect::RoutingProfile
 */
export declare function getRoutingProfile(args: GetRoutingProfileArgs, opts?: pulumi.InvokeOptions): Promise<GetRoutingProfileResult>;
export interface GetRoutingProfileArgs {
    /**
     * The Amazon Resource Name (ARN) of the routing profile.
     */
    routingProfileArn: string;
}
export interface GetRoutingProfileResult {
    /**
     * Whether agents with this routing profile will have their routing order calculated based on longest idle time or time since their last inbound contact.
     */
    readonly agentAvailabilityTimer?: enums.connect.RoutingProfileAgentAvailabilityTimer;
    /**
     * The identifier of the default outbound queue for this routing profile.
     */
    readonly defaultOutboundQueueArn?: string;
    /**
     * The description of the routing profile.
     */
    readonly description?: string;
    /**
     * The identifier of the Amazon Connect instance.
     */
    readonly instanceArn?: string;
    /**
     * The channels agents can handle in the Contact Control Panel (CCP) for this routing profile.
     */
    readonly mediaConcurrencies?: outputs.connect.RoutingProfileMediaConcurrency[];
    /**
     * The name of the routing profile.
     */
    readonly name?: string;
    /**
     * The queues to associate with this routing profile.
     */
    readonly queueConfigs?: outputs.connect.RoutingProfileQueueConfig[];
    /**
     * The Amazon Resource Name (ARN) of the routing profile.
     */
    readonly routingProfileArn?: string;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource Type definition for AWS::Connect::RoutingProfile
 */
export declare function getRoutingProfileOutput(args: GetRoutingProfileOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetRoutingProfileResult>;
export interface GetRoutingProfileOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the routing profile.
     */
    routingProfileArn: pulumi.Input<string>;
}
