import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * AWS Datazone Environment Profile is pre-configured set of resources and blueprints that provide reusable templates for creating environments.
 */
export declare class EnvironmentProfile extends pulumi.CustomResource {
    /**
     * Get an existing EnvironmentProfile resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): EnvironmentProfile;
    /**
     * Returns true if the given object is an instance of EnvironmentProfile.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is EnvironmentProfile;
    /**
     * The AWS account in which the Amazon DataZone environment is created.
     */
    readonly awsAccountId: pulumi.Output<string>;
    /**
     * The AWS region in which this environment profile is created.
     */
    readonly awsAccountRegion: pulumi.Output<string>;
    /**
     * The ID of this Amazon DataZone environment profile.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The timestamp of when this environment profile was created.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * The Amazon DataZone user who created this environment profile.
     */
    readonly createdBy: pulumi.Output<string>;
    /**
     * The description of this Amazon DataZone environment profile.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The ID of the Amazon DataZone domain in which this environment profile is created.
     */
    readonly domainId: pulumi.Output<string>;
    /**
     * The ID of the Amazon DataZone domain in which this environment profile is created.
     */
    readonly domainIdentifier: pulumi.Output<string>;
    /**
     * The ID of the blueprint with which this environment profile is created.
     */
    readonly environmentBlueprintId: pulumi.Output<string>;
    /**
     * The ID of the blueprint with which this environment profile is created.
     */
    readonly environmentBlueprintIdentifier: pulumi.Output<string>;
    /**
     * The name of this Amazon DataZone environment profile.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The identifier of the project in which to create the environment profile.
     */
    readonly projectId: pulumi.Output<string>;
    /**
     * The identifier of the project in which to create the environment profile.
     */
    readonly projectIdentifier: pulumi.Output<string>;
    /**
     * The timestamp of when this environment profile was updated.
     */
    readonly updatedAt: pulumi.Output<string>;
    /**
     * The user parameters of this Amazon DataZone environment profile.
     */
    readonly userParameters: pulumi.Output<outputs.datazone.EnvironmentProfileEnvironmentParameter[] | undefined>;
    /**
     * Create a EnvironmentProfile resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: EnvironmentProfileArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a EnvironmentProfile resource.
 */
export interface EnvironmentProfileArgs {
    /**
     * The AWS account in which the Amazon DataZone environment is created.
     */
    awsAccountId: pulumi.Input<string>;
    /**
     * The AWS region in which this environment profile is created.
     */
    awsAccountRegion: pulumi.Input<string>;
    /**
     * The description of this Amazon DataZone environment profile.
     */
    description?: pulumi.Input<string>;
    /**
     * The ID of the Amazon DataZone domain in which this environment profile is created.
     */
    domainIdentifier: pulumi.Input<string>;
    /**
     * The ID of the blueprint with which this environment profile is created.
     */
    environmentBlueprintIdentifier: pulumi.Input<string>;
    /**
     * The name of this Amazon DataZone environment profile.
     */
    name?: pulumi.Input<string>;
    /**
     * The identifier of the project in which to create the environment profile.
     */
    projectIdentifier: pulumi.Input<string>;
    /**
     * The user parameters of this Amazon DataZone environment profile.
     */
    userParameters?: pulumi.Input<pulumi.Input<inputs.datazone.EnvironmentProfileEnvironmentParameterArgs>[]>;
}
