import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Subscription targets enables one to access the data to which you have subscribed in your projects.
 */
export declare function getSubscriptionTarget(args: GetSubscriptionTargetArgs, opts?: pulumi.InvokeOptions): Promise<GetSubscriptionTargetResult>;
export interface GetSubscriptionTargetArgs {
    /**
     * The ID of the Amazon DataZone domain in which subscription target is created.
     */
    domainId: string;
    /**
     * The ID of the environment in which subscription target is created.
     */
    environmentId: string;
    /**
     * The ID of the subscription target.
     */
    id: string;
}
export interface GetSubscriptionTargetResult {
    /**
     * The asset types that can be included in the subscription target.
     */
    readonly applicableAssetTypes?: string[];
    /**
     * The authorized principals of the subscription target.
     */
    readonly authorizedPrincipals?: string[];
    /**
     * The timestamp of when the subscription target was created.
     */
    readonly createdAt?: string;
    /**
     * The Amazon DataZone user who created the subscription target.
     */
    readonly createdBy?: string;
    /**
     * The ID of the Amazon DataZone domain in which subscription target is created.
     */
    readonly domainId?: string;
    /**
     * The ID of the environment in which subscription target is created.
     */
    readonly environmentId?: string;
    /**
     * The ID of the subscription target.
     */
    readonly id?: string;
    /**
     * The manage access role that is used to create the subscription target.
     */
    readonly manageAccessRole?: string;
    /**
     * The name of the subscription target.
     */
    readonly name?: string;
    /**
     * The identifier of the project specified in the subscription target.
     */
    readonly projectId?: string;
    /**
     * The provider of the subscription target.
     */
    readonly provider?: string;
    /**
     * The configuration of the subscription target.
     */
    readonly subscriptionTargetConfig?: outputs.datazone.SubscriptionTargetForm[];
    /**
     * The timestamp of when the subscription target was updated.
     */
    readonly updatedAt?: string;
    /**
     * The Amazon DataZone user who updated the subscription target.
     */
    readonly updatedBy?: string;
}
/**
 * Subscription targets enables one to access the data to which you have subscribed in your projects.
 */
export declare function getSubscriptionTargetOutput(args: GetSubscriptionTargetOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetSubscriptionTargetResult>;
export interface GetSubscriptionTargetOutputArgs {
    /**
     * The ID of the Amazon DataZone domain in which subscription target is created.
     */
    domainId: pulumi.Input<string>;
    /**
     * The ID of the environment in which subscription target is created.
     */
    environmentId: pulumi.Input<string>;
    /**
     * The ID of the subscription target.
     */
    id: pulumi.Input<string>;
}
