import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Subscription targets enables one to access the data to which you have subscribed in your projects.
 */
export declare class SubscriptionTarget extends pulumi.CustomResource {
    /**
     * Get an existing SubscriptionTarget resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): SubscriptionTarget;
    /**
     * Returns true if the given object is an instance of SubscriptionTarget.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SubscriptionTarget;
    /**
     * The asset types that can be included in the subscription target.
     */
    readonly applicableAssetTypes: pulumi.Output<string[]>;
    /**
     * The authorized principals of the subscription target.
     */
    readonly authorizedPrincipals: pulumi.Output<string[]>;
    /**
     * The ID of the subscription target.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The timestamp of when the subscription target was created.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * The Amazon DataZone user who created the subscription target.
     */
    readonly createdBy: pulumi.Output<string>;
    /**
     * The ID of the Amazon DataZone domain in which subscription target is created.
     */
    readonly domainId: pulumi.Output<string>;
    /**
     * The ID of the Amazon DataZone domain in which subscription target would be created.
     */
    readonly domainIdentifier: pulumi.Output<string>;
    /**
     * The ID of the environment in which subscription target is created.
     */
    readonly environmentId: pulumi.Output<string>;
    /**
     * The ID of the environment in which subscription target would be created.
     */
    readonly environmentIdentifier: pulumi.Output<string>;
    /**
     * The manage access role that is used to create the subscription target.
     */
    readonly manageAccessRole: pulumi.Output<string | undefined>;
    /**
     * The name of the subscription target.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The identifier of the project specified in the subscription target.
     */
    readonly projectId: pulumi.Output<string>;
    /**
     * The provider of the subscription target.
     */
    readonly provider: pulumi.Output<string | undefined>;
    /**
     * The configuration of the subscription target.
     */
    readonly subscriptionTargetConfig: pulumi.Output<outputs.datazone.SubscriptionTargetForm[]>;
    /**
     * The type of the subscription target.
     */
    readonly type: pulumi.Output<string>;
    /**
     * The timestamp of when the subscription target was updated.
     */
    readonly updatedAt: pulumi.Output<string>;
    /**
     * The Amazon DataZone user who updated the subscription target.
     */
    readonly updatedBy: pulumi.Output<string>;
    /**
     * Create a SubscriptionTarget resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SubscriptionTargetArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a SubscriptionTarget resource.
 */
export interface SubscriptionTargetArgs {
    /**
     * The asset types that can be included in the subscription target.
     */
    applicableAssetTypes: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The authorized principals of the subscription target.
     */
    authorizedPrincipals: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The ID of the Amazon DataZone domain in which subscription target would be created.
     */
    domainIdentifier: pulumi.Input<string>;
    /**
     * The ID of the environment in which subscription target would be created.
     */
    environmentIdentifier: pulumi.Input<string>;
    /**
     * The manage access role that is used to create the subscription target.
     */
    manageAccessRole?: pulumi.Input<string>;
    /**
     * The name of the subscription target.
     */
    name?: pulumi.Input<string>;
    /**
     * The provider of the subscription target.
     */
    provider?: pulumi.Input<string>;
    /**
     * The configuration of the subscription target.
     */
    subscriptionTargetConfig: pulumi.Input<pulumi.Input<inputs.datazone.SubscriptionTargetFormArgs>[]>;
    /**
     * The type of the subscription target.
     */
    type: pulumi.Input<string>;
}
