import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::DMS::DataProvider
 */
export declare class DataProvider extends pulumi.CustomResource {
    /**
     * Get an existing DataProvider resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): DataProvider;
    /**
     * Returns true if the given object is an instance of DataProvider.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DataProvider;
    /**
     * The data provider ARN.
     */
    readonly dataProviderArn: pulumi.Output<string>;
    /**
     * The data provider creation time.
     */
    readonly dataProviderCreationTime: pulumi.Output<string>;
    /**
     * The property describes an identifier for the data provider. It is used for describing/deleting/modifying can be name/arn
     */
    readonly dataProviderIdentifier: pulumi.Output<string | undefined>;
    /**
     * The property describes a name to identify the data provider.
     */
    readonly dataProviderName: pulumi.Output<string | undefined>;
    /**
     * The optional description of the data provider.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The property describes a data engine for the data provider.
     */
    readonly engine: pulumi.Output<enums.dms.DataProviderEngine>;
    /**
     * The property describes the exact settings which can be modified
     */
    readonly exactSettings: pulumi.Output<boolean | undefined>;
    /**
     * The property identifies the exact type of settings for the data provider.
     */
    readonly settings: pulumi.Output<outputs.dms.SettingsProperties | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a DataProvider resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DataProviderArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a DataProvider resource.
 */
export interface DataProviderArgs {
    /**
     * The property describes an identifier for the data provider. It is used for describing/deleting/modifying can be name/arn
     */
    dataProviderIdentifier?: pulumi.Input<string>;
    /**
     * The property describes a name to identify the data provider.
     */
    dataProviderName?: pulumi.Input<string>;
    /**
     * The optional description of the data provider.
     */
    description?: pulumi.Input<string>;
    /**
     * The property describes a data engine for the data provider.
     */
    engine: pulumi.Input<enums.dms.DataProviderEngine>;
    /**
     * The property describes the exact settings which can be modified
     */
    exactSettings?: pulumi.Input<boolean>;
    /**
     * The property identifies the exact type of settings for the data provider.
     */
    settings?: pulumi.Input<inputs.dms.SettingsPropertiesArgs>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
