import * as pulumi from "@pulumi/pulumi";
/**
 * Associates an AWS Identity and Access Management (IAM) role with an AWS Certificate Manager (ACM) certificate. This association is based on Amazon Resource Names and it enables the certificate to be used by the ACM for Nitro Enclaves application inside an enclave.
 */
export declare function getEnclaveCertificateIamRoleAssociation(args: GetEnclaveCertificateIamRoleAssociationArgs, opts?: pulumi.InvokeOptions): Promise<GetEnclaveCertificateIamRoleAssociationResult>;
export interface GetEnclaveCertificateIamRoleAssociationArgs {
    /**
     * The Amazon Resource Name (ARN) of the ACM certificate with which to associate the IAM role.
     */
    certificateArn: string;
    /**
     * The Amazon Resource Name (ARN) of the IAM role to associate with the ACM certificate. You can associate up to 16 IAM roles with an ACM certificate.
     */
    roleArn: string;
}
export interface GetEnclaveCertificateIamRoleAssociationResult {
    /**
     * The name of the Amazon S3 bucket to which the certificate was uploaded.
     */
    readonly certificateS3BucketName?: string;
    /**
     * The Amazon S3 object key where the certificate, certificate chain, and encrypted private key bundle are stored.
     */
    readonly certificateS3ObjectKey?: string;
    /**
     * The ID of the AWS KMS CMK used to encrypt the private key of the certificate.
     */
    readonly encryptionKmsKeyId?: string;
}
/**
 * Associates an AWS Identity and Access Management (IAM) role with an AWS Certificate Manager (ACM) certificate. This association is based on Amazon Resource Names and it enables the certificate to be used by the ACM for Nitro Enclaves application inside an enclave.
 */
export declare function getEnclaveCertificateIamRoleAssociationOutput(args: GetEnclaveCertificateIamRoleAssociationOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetEnclaveCertificateIamRoleAssociationResult>;
export interface GetEnclaveCertificateIamRoleAssociationOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the ACM certificate with which to associate the IAM role.
     */
    certificateArn: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) of the IAM role to associate with the ACM certificate. You can associate up to 16 IAM roles with an ACM certificate.
     */
    roleArn: pulumi.Input<string>;
}
