import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The AWS::EC2::VerifiedAccessTrustProvider type describes a verified access trust provider
 */
export declare function getVerifiedAccessTrustProvider(args: GetVerifiedAccessTrustProviderArgs, opts?: pulumi.InvokeOptions): Promise<GetVerifiedAccessTrustProviderResult>;
export interface GetVerifiedAccessTrustProviderArgs {
    /**
     * The ID of the Amazon Web Services Verified Access trust provider.
     */
    verifiedAccessTrustProviderId: string;
}
export interface GetVerifiedAccessTrustProviderResult {
    /**
     * The creation time.
     */
    readonly creationTime?: string;
    /**
     * A description for the Amazon Web Services Verified Access trust provider.
     */
    readonly description?: string;
    /**
     * The last updated time.
     */
    readonly lastUpdatedTime?: string;
    /**
     * The OpenID Connect (OIDC) options.
     */
    readonly nativeApplicationOidcOptions?: outputs.ec2.VerifiedAccessTrustProviderNativeApplicationOidcOptions;
    /**
     * The options for an OpenID Connect-compatible user-identity trust provider.
     */
    readonly oidcOptions?: outputs.ec2.VerifiedAccessTrustProviderOidcOptions;
    /**
     * The configuration options for customer provided KMS encryption.
     */
    readonly sseSpecification?: outputs.ec2.SseSpecificationProperties;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
    /**
     * The ID of the Amazon Web Services Verified Access trust provider.
     */
    readonly verifiedAccessTrustProviderId?: string;
}
/**
 * The AWS::EC2::VerifiedAccessTrustProvider type describes a verified access trust provider
 */
export declare function getVerifiedAccessTrustProviderOutput(args: GetVerifiedAccessTrustProviderOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetVerifiedAccessTrustProviderResult>;
export interface GetVerifiedAccessTrustProviderOutputArgs {
    /**
     * The ID of the Amazon Web Services Verified Access trust provider.
     */
    verifiedAccessTrustProviderId: pulumi.Input<string>;
}
