import * as pulumi from "@pulumi/pulumi";
/**
 * Resource Type definition for AWS::EC2::Host
 */
export declare class Host extends pulumi.CustomResource {
    /**
     * Get an existing Host resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Host;
    /**
     * Returns true if the given object is an instance of Host.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Host;
    /**
     * The ID of the Outpost hardware asset.
     */
    readonly assetId: pulumi.Output<string | undefined>;
    /**
     * Indicates whether the host accepts any untargeted instance launches that match its instance type configuration, or if it only accepts Host tenancy instance launches that specify its unique host ID.
     */
    readonly autoPlacement: pulumi.Output<string | undefined>;
    /**
     * The Availability Zone in which to allocate the Dedicated Host.
     */
    readonly availabilityZone: pulumi.Output<string>;
    /**
     * ID of the host created.
     */
    readonly hostId: pulumi.Output<string>;
    /**
     * Automatically allocates a new dedicated host and moves your instances on to it if a degradation is detected on your current host.
     */
    readonly hostMaintenance: pulumi.Output<string | undefined>;
    /**
     * Indicates whether to enable or disable host recovery for the Dedicated Host. Host recovery is disabled by default.
     */
    readonly hostRecovery: pulumi.Output<string | undefined>;
    /**
     * Specifies the instance family to be supported by the Dedicated Hosts. If you specify an instance family, the Dedicated Hosts support multiple instance types within that instance family.
     */
    readonly instanceFamily: pulumi.Output<string | undefined>;
    /**
     * Specifies the instance type to be supported by the Dedicated Hosts. If you specify an instance type, the Dedicated Hosts support instances of the specified instance type only.
     */
    readonly instanceType: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the Amazon Web Services Outpost on which to allocate the Dedicated Host.
     */
    readonly outpostArn: pulumi.Output<string | undefined>;
    /**
     * Create a Host resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: HostArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Host resource.
 */
export interface HostArgs {
    /**
     * The ID of the Outpost hardware asset.
     */
    assetId?: pulumi.Input<string>;
    /**
     * Indicates whether the host accepts any untargeted instance launches that match its instance type configuration, or if it only accepts Host tenancy instance launches that specify its unique host ID.
     */
    autoPlacement?: pulumi.Input<string>;
    /**
     * The Availability Zone in which to allocate the Dedicated Host.
     */
    availabilityZone: pulumi.Input<string>;
    /**
     * Automatically allocates a new dedicated host and moves your instances on to it if a degradation is detected on your current host.
     */
    hostMaintenance?: pulumi.Input<string>;
    /**
     * Indicates whether to enable or disable host recovery for the Dedicated Host. Host recovery is disabled by default.
     */
    hostRecovery?: pulumi.Input<string>;
    /**
     * Specifies the instance family to be supported by the Dedicated Hosts. If you specify an instance family, the Dedicated Hosts support multiple instance types within that instance family.
     */
    instanceFamily?: pulumi.Input<string>;
    /**
     * Specifies the instance type to be supported by the Dedicated Hosts. If you specify an instance type, the Dedicated Hosts support instances of the specified instance type only.
     */
    instanceType?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) of the Amazon Web Services Outpost on which to allocate the Dedicated Host.
     */
    outpostArn?: pulumi.Input<string>;
}
