import * as pulumi from "@pulumi/pulumi";
/**
 * A pseudo-resource that manages which of your ECS task sets is primary.
 */
export declare class PrimaryTaskSet extends pulumi.CustomResource {
    /**
     * Get an existing PrimaryTaskSet resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): PrimaryTaskSet;
    /**
     * Returns true if the given object is an instance of PrimaryTaskSet.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is PrimaryTaskSet;
    /**
     * The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service to create the task set in.
     */
    readonly cluster: pulumi.Output<string>;
    /**
     * The short name or full Amazon Resource Name (ARN) of the service to create the task set in.
     */
    readonly service: pulumi.Output<string>;
    /**
     * The ID or full Amazon Resource Name (ARN) of the task set.
     */
    readonly taskSetId: pulumi.Output<string>;
    /**
     * Create a PrimaryTaskSet resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: PrimaryTaskSetArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a PrimaryTaskSet resource.
 */
export interface PrimaryTaskSetArgs {
    /**
     * The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service to create the task set in.
     */
    cluster: pulumi.Input<string>;
    /**
     * The short name or full Amazon Resource Name (ARN) of the service to create the task set in.
     */
    service: pulumi.Input<string>;
    /**
     * The ID or full Amazon Resource Name (ARN) of the task set.
     */
    taskSetId: pulumi.Input<string>;
}
