import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::Events::ApiDestination.
 */
export declare class ApiDestination extends pulumi.CustomResource {
    /**
     * Get an existing ApiDestination resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ApiDestination;
    /**
     * Returns true if the given object is an instance of ApiDestination.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ApiDestination;
    /**
     * The arn of the api destination.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The arn of the connection.
     */
    readonly connectionArn: pulumi.Output<string>;
    /**
     * A description for the API destination to create.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The method to use for the request to the HTTP invocation endpoint.
     */
    readonly httpMethod: pulumi.Output<enums.events.ApiDestinationHttpMethod>;
    /**
     * Url endpoint to invoke.
     */
    readonly invocationEndpoint: pulumi.Output<string>;
    /**
     * The maximum number of requests per second to send to the HTTP invocation endpoint.
     */
    readonly invocationRateLimitPerSecond: pulumi.Output<number | undefined>;
    /**
     * Name of the apiDestination.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * Create a ApiDestination resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ApiDestinationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ApiDestination resource.
 */
export interface ApiDestinationArgs {
    /**
     * The arn of the connection.
     */
    connectionArn: pulumi.Input<string>;
    /**
     * A description for the API destination to create.
     */
    description?: pulumi.Input<string>;
    /**
     * The method to use for the request to the HTTP invocation endpoint.
     */
    httpMethod: pulumi.Input<enums.events.ApiDestinationHttpMethod>;
    /**
     * Url endpoint to invoke.
     */
    invocationEndpoint: pulumi.Input<string>;
    /**
     * The maximum number of requests per second to send to the HTTP invocation endpoint.
     */
    invocationRateLimitPerSecond?: pulumi.Input<number>;
    /**
     * Name of the apiDestination.
     */
    name?: pulumi.Input<string>;
}
