import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource schema for AWS::ImageBuilder::DistributionConfiguration
 */
export declare class DistributionConfiguration extends pulumi.CustomResource {
    /**
     * Get an existing DistributionConfiguration resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): DistributionConfiguration;
    /**
     * Returns true if the given object is an instance of DistributionConfiguration.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DistributionConfiguration;
    /**
     * The Amazon Resource Name (ARN) of the distribution configuration.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The description of the distribution configuration.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The distributions of the distribution configuration.
     */
    readonly distributions: pulumi.Output<outputs.imagebuilder.DistributionConfigurationDistribution[]>;
    /**
     * The name of the distribution configuration.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The tags associated with the component.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a DistributionConfiguration resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DistributionConfigurationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a DistributionConfiguration resource.
 */
export interface DistributionConfigurationArgs {
    /**
     * The description of the distribution configuration.
     */
    description?: pulumi.Input<string>;
    /**
     * The distributions of the distribution configuration.
     */
    distributions: pulumi.Input<pulumi.Input<inputs.imagebuilder.DistributionConfigurationDistributionArgs>[]>;
    /**
     * The name of the distribution configuration.
     */
    name?: pulumi.Input<string>;
    /**
     * The tags associated with the component.
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
