import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * An aggregated metric of certain devices in your fleet
 */
export declare class FleetMetric extends pulumi.CustomResource {
    /**
     * Get an existing FleetMetric resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): FleetMetric;
    /**
     * Returns true if the given object is an instance of FleetMetric.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is FleetMetric;
    /**
     * The aggregation field to perform aggregation and metric emission
     */
    readonly aggregationField: pulumi.Output<string | undefined>;
    /**
     * The type of the aggregation query.
     */
    readonly aggregationType: pulumi.Output<outputs.iot.FleetMetricAggregationType | undefined>;
    /**
     * The creation date of a fleet metric
     */
    readonly creationDate: pulumi.Output<string>;
    /**
     * The description of a fleet metric
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The index name of a fleet metric
     */
    readonly indexName: pulumi.Output<string | undefined>;
    /**
     * The last modified date of a fleet metric
     */
    readonly lastModifiedDate: pulumi.Output<string>;
    /**
     * The Amazon Resource Number (ARN) of a fleet metric metric
     */
    readonly metricArn: pulumi.Output<string>;
    /**
     * The name of the fleet metric
     */
    readonly metricName: pulumi.Output<string>;
    /**
     * The period of metric emission in seconds
     */
    readonly period: pulumi.Output<number | undefined>;
    /**
     * The Fleet Indexing query used by a fleet metric
     */
    readonly queryString: pulumi.Output<string | undefined>;
    /**
     * The version of a Fleet Indexing query used by a fleet metric
     */
    readonly queryVersion: pulumi.Output<string | undefined>;
    /**
     * An array of key-value pairs to apply to this resource
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The unit of data points emitted by a fleet metric
     */
    readonly unit: pulumi.Output<string | undefined>;
    /**
     * The version of a fleet metric
     */
    readonly version: pulumi.Output<number>;
    /**
     * Create a FleetMetric resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: FleetMetricArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a FleetMetric resource.
 */
export interface FleetMetricArgs {
    /**
     * The aggregation field to perform aggregation and metric emission
     */
    aggregationField?: pulumi.Input<string>;
    /**
     * The type of the aggregation query.
     */
    aggregationType?: pulumi.Input<inputs.iot.FleetMetricAggregationTypeArgs>;
    /**
     * The description of a fleet metric
     */
    description?: pulumi.Input<string>;
    /**
     * The index name of a fleet metric
     */
    indexName?: pulumi.Input<string>;
    /**
     * The name of the fleet metric
     */
    metricName?: pulumi.Input<string>;
    /**
     * The period of metric emission in seconds
     */
    period?: pulumi.Input<number>;
    /**
     * The Fleet Indexing query used by a fleet metric
     */
    queryString?: pulumi.Input<string>;
    /**
     * The version of a Fleet Indexing query used by a fleet metric
     */
    queryVersion?: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The unit of data points emitted by a fleet metric
     */
    unit?: pulumi.Input<string>;
}
