import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * Logging Options enable you to configure your IoT V2 logging role and default logging level so that you can monitor progress events logs as it passes from your devices through Iot core service.
 */
export declare class Logging extends pulumi.CustomResource {
    /**
     * Get an existing Logging resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Logging;
    /**
     * Returns true if the given object is an instance of Logging.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Logging;
    /**
     * Your 12-digit account ID (used as the primary identifier for the CloudFormation resource).
     */
    readonly accountId: pulumi.Output<string>;
    /**
     * The log level to use. Valid values are: ERROR, WARN, INFO, DEBUG, or DISABLED.
     */
    readonly defaultLogLevel: pulumi.Output<enums.iot.LoggingDefaultLogLevel>;
    /**
     * The ARN of the role that allows IoT to write to Cloudwatch logs.
     */
    readonly roleArn: pulumi.Output<string>;
    /**
     * Create a Logging resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: LoggingArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Logging resource.
 */
export interface LoggingArgs {
    /**
     * Your 12-digit account ID (used as the primary identifier for the CloudFormation resource).
     */
    accountId: pulumi.Input<string>;
    /**
     * The log level to use. Valid values are: ERROR, WARN, INFO, DEBUG, or DISABLED.
     */
    defaultLogLevel: pulumi.Input<enums.iot.LoggingDefaultLogLevel>;
    /**
     * The ARN of the role that allows IoT to write to Cloudwatch logs.
     */
    roleArn: pulumi.Input<string>;
}
