import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Use the AWS::IoT::RoleAlias resource to declare an AWS IoT RoleAlias.
 */
export declare class RoleAlias extends pulumi.CustomResource {
    /**
     * Get an existing RoleAlias resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): RoleAlias;
    /**
     * Returns true if the given object is an instance of RoleAlias.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is RoleAlias;
    /**
     * The number of seconds for which the credential is valid.
     */
    readonly credentialDurationSeconds: pulumi.Output<number | undefined>;
    /**
     * The role alias.
     */
    readonly roleAlias: pulumi.Output<string | undefined>;
    /**
     * The role alias ARN.
     */
    readonly roleAliasArn: pulumi.Output<string>;
    /**
     * The role ARN.
     */
    readonly roleArn: pulumi.Output<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     *
     * For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) .
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a RoleAlias resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: RoleAliasArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a RoleAlias resource.
 */
export interface RoleAliasArgs {
    /**
     * The number of seconds for which the credential is valid.
     */
    credentialDurationSeconds?: pulumi.Input<number>;
    /**
     * The role alias.
     */
    roleAlias?: pulumi.Input<string>;
    /**
     * The role ARN.
     */
    roleArn: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     *
     * For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) .
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
