import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Kinesis::Stream
 */
export declare class Stream extends pulumi.CustomResource {
    /**
     * Get an existing Stream resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Stream;
    /**
     * Returns true if the given object is an instance of Stream.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Stream;
    /**
     * The Amazon resource name (ARN) of the Kinesis stream
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The name of the Kinesis stream.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * The number of hours for the data records that are stored in shards to remain accessible.
     */
    readonly retentionPeriodHours: pulumi.Output<number | undefined>;
    /**
     * The number of shards that the stream uses. Required when StreamMode = PROVISIONED is passed.
     */
    readonly shardCount: pulumi.Output<number | undefined>;
    /**
     * When specified, enables or updates server-side encryption using an AWS KMS key for a specified stream.
     */
    readonly streamEncryption: pulumi.Output<outputs.kinesis.StreamEncryption | undefined>;
    /**
     * The mode in which the stream is running.
     */
    readonly streamModeDetails: pulumi.Output<outputs.kinesis.StreamModeDetails | undefined>;
    /**
     * An arbitrary set of tags (key–value pairs) to associate with the Kinesis stream.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Stream resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: StreamArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Stream resource.
 */
export interface StreamArgs {
    /**
     * The name of the Kinesis stream.
     */
    name?: pulumi.Input<string>;
    /**
     * The number of hours for the data records that are stored in shards to remain accessible.
     */
    retentionPeriodHours?: pulumi.Input<number>;
    /**
     * The number of shards that the stream uses. Required when StreamMode = PROVISIONED is passed.
     */
    shardCount?: pulumi.Input<number>;
    /**
     * When specified, enables or updates server-side encryption using an AWS KMS key for a specified stream.
     */
    streamEncryption?: pulumi.Input<inputs.kinesis.StreamEncryptionArgs>;
    /**
     * The mode in which the stream is running.
     */
    streamModeDetails?: pulumi.Input<inputs.kinesis.StreamModeDetailsArgs>;
    /**
     * An arbitrary set of tags (key–value pairs) to associate with the Kinesis stream.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
