import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Amazon Lex conversational bot performing automated tasks such as ordering a pizza, booking a hotel, and so on.
 */
export declare class Bot extends pulumi.CustomResource {
    /**
     * Get an existing Bot resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Bot;
    /**
     * Returns true if the given object is an instance of Bot.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Bot;
    /**
     * The Amazon Resource Name (ARN) of the bot.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Specifies whether to build the bot locales after bot creation completes.
     */
    readonly autoBuildBotLocales: pulumi.Output<boolean | undefined>;
    /**
     * The unique identifier of the bot.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The Amazon S3 location of files used to import a bot. The files must be in the import format specified in [JSON format for importing and exporting](https://docs.aws.amazon.com/lexv2/latest/dg/import-export-format.html) in the *Amazon Lex developer guide.*
     */
    readonly botFileS3Location: pulumi.Output<outputs.lex.BotS3Location | undefined>;
    /**
     * List of bot locales
     */
    readonly botLocales: pulumi.Output<outputs.lex.BotLocale[] | undefined>;
    /**
     * A list of tags to add to the bot, which can only be added at bot creation.
     */
    readonly botTags: pulumi.Output<outputs.lex.BotTag[] | undefined>;
    /**
     * Data privacy setting of the Bot.
     */
    readonly dataPrivacy: pulumi.Output<outputs.lex.DataPrivacyProperties>;
    /**
     * The description of the version.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * IdleSessionTTLInSeconds of the resource
     */
    readonly idleSessionTtlInSeconds: pulumi.Output<number>;
    /**
     * The name of the bot locale.
     */
    readonly name: pulumi.Output<string>;
    readonly replication: pulumi.Output<outputs.lex.BotReplication | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the IAM role used to build and run the bot.
     */
    readonly roleArn: pulumi.Output<string>;
    /**
     * Specifies configuration settings for the alias used to test the bot. If the `TestBotAliasSettings` property is not specified, the settings are configured with default values.
     */
    readonly testBotAliasSettings: pulumi.Output<outputs.lex.BotTestBotAliasSettings | undefined>;
    /**
     * A list of tags to add to the test alias for a bot, , which can only be added at bot/bot alias creation.
     */
    readonly testBotAliasTags: pulumi.Output<outputs.lex.BotTag[] | undefined>;
    /**
     * Create a Bot resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: BotArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Bot resource.
 */
export interface BotArgs {
    /**
     * Specifies whether to build the bot locales after bot creation completes.
     */
    autoBuildBotLocales?: pulumi.Input<boolean>;
    /**
     * The Amazon S3 location of files used to import a bot. The files must be in the import format specified in [JSON format for importing and exporting](https://docs.aws.amazon.com/lexv2/latest/dg/import-export-format.html) in the *Amazon Lex developer guide.*
     */
    botFileS3Location?: pulumi.Input<inputs.lex.BotS3LocationArgs>;
    /**
     * List of bot locales
     */
    botLocales?: pulumi.Input<pulumi.Input<inputs.lex.BotLocaleArgs>[]>;
    /**
     * A list of tags to add to the bot, which can only be added at bot creation.
     */
    botTags?: pulumi.Input<pulumi.Input<inputs.lex.BotTagArgs>[]>;
    /**
     * Data privacy setting of the Bot.
     */
    dataPrivacy: pulumi.Input<inputs.lex.DataPrivacyPropertiesArgs>;
    /**
     * The description of the version.
     */
    description?: pulumi.Input<string>;
    /**
     * IdleSessionTTLInSeconds of the resource
     */
    idleSessionTtlInSeconds: pulumi.Input<number>;
    /**
     * The name of the bot locale.
     */
    name?: pulumi.Input<string>;
    replication?: pulumi.Input<inputs.lex.BotReplicationArgs>;
    /**
     * The Amazon Resource Name (ARN) of the IAM role used to build and run the bot.
     */
    roleArn: pulumi.Input<string>;
    /**
     * Specifies configuration settings for the alias used to test the bot. If the `TestBotAliasSettings` property is not specified, the settings are configured with default values.
     */
    testBotAliasSettings?: pulumi.Input<inputs.lex.BotTestBotAliasSettingsArgs>;
    /**
     * A list of tags to add to the test alias for a bot, , which can only be added at bot/bot alias creation.
     */
    testBotAliasTags?: pulumi.Input<pulumi.Input<inputs.lex.BotTagArgs>[]>;
}
