import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::LookoutMetrics::Alert
 */
export declare class Alert extends pulumi.CustomResource {
    /**
     * Get an existing Alert resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Alert;
    /**
     * Returns true if the given object is an instance of Alert.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Alert;
    /**
     * The action to be taken by the alert when an anomaly is detected.
     */
    readonly action: pulumi.Output<outputs.lookoutmetrics.AlertAction>;
    /**
     * A description for the alert.
     */
    readonly alertDescription: pulumi.Output<string | undefined>;
    /**
     * The name of the alert. If not provided, a name is generated automatically.
     */
    readonly alertName: pulumi.Output<string | undefined>;
    /**
     * A number between 0 and 100 (inclusive) that tunes the sensitivity of the alert.
     */
    readonly alertSensitivityThreshold: pulumi.Output<number>;
    /**
     * The Amazon resource name (ARN) of the Anomaly Detector to alert.
     */
    readonly anomalyDetectorArn: pulumi.Output<string>;
    /**
     * ARN assigned to the alert.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Create a Alert resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AlertArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Alert resource.
 */
export interface AlertArgs {
    /**
     * The action to be taken by the alert when an anomaly is detected.
     */
    action: pulumi.Input<inputs.lookoutmetrics.AlertActionArgs>;
    /**
     * A description for the alert.
     */
    alertDescription?: pulumi.Input<string>;
    /**
     * The name of the alert. If not provided, a name is generated automatically.
     */
    alertName?: pulumi.Input<string>;
    /**
     * A number between 0 and 100 (inclusive) that tunes the sensitivity of the alert.
     */
    alertSensitivityThreshold: pulumi.Input<number>;
    /**
     * The Amazon resource name (ARN) of the Anomaly Detector to alert.
     */
    anomalyDetectorArn: pulumi.Input<string>;
}
