import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::MediaPackage::OriginEndpoint
 */
export declare class OriginEndpoint extends pulumi.CustomResource {
    /**
     * Get an existing OriginEndpoint resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): OriginEndpoint;
    /**
     * Returns true if the given object is an instance of OriginEndpoint.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is OriginEndpoint;
    /**
     * The Amazon Resource Name (ARN) assigned to the OriginEndpoint.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Parameters for CDN authorization.
     */
    readonly authorization: pulumi.Output<outputs.mediapackage.OriginEndpointAuthorization | undefined>;
    /**
     * The ID of the OriginEndpoint.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The ID of the Channel the OriginEndpoint is associated with.
     */
    readonly channelId: pulumi.Output<string>;
    /**
     * Parameters for Common Media Application Format (CMAF) packaging.
     */
    readonly cmafPackage: pulumi.Output<outputs.mediapackage.OriginEndpointCmafPackage | undefined>;
    /**
     * Parameters for DASH packaging.
     */
    readonly dashPackage: pulumi.Output<outputs.mediapackage.OriginEndpointDashPackage | undefined>;
    /**
     * A short text description of the OriginEndpoint.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Parameters for Apple HLS packaging.
     */
    readonly hlsPackage: pulumi.Output<outputs.mediapackage.OriginEndpointHlsPackage | undefined>;
    /**
     * A short string appended to the end of the OriginEndpoint URL.
     */
    readonly manifestName: pulumi.Output<string | undefined>;
    /**
     * Parameters for Microsoft Smooth Streaming packaging.
     */
    readonly mssPackage: pulumi.Output<outputs.mediapackage.OriginEndpointMssPackage | undefined>;
    /**
     * Control whether origination of video is allowed for this OriginEndpoint. If set to ALLOW, the OriginEndpoint may by requested, pursuant to any other form of access control. If set to DENY, the OriginEndpoint may not be requested. This can be helpful for Live to VOD harvesting, or for temporarily disabling origination
     */
    readonly origination: pulumi.Output<enums.mediapackage.OriginEndpointOrigination | undefined>;
    /**
     * Maximum duration (seconds) of content to retain for startover playback. If not specified, startover playback will be disabled for the OriginEndpoint.
     */
    readonly startoverWindowSeconds: pulumi.Output<number | undefined>;
    /**
     * A collection of tags associated with a resource
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Amount of delay (seconds) to enforce on the playback of live content. If not specified, there will be no time delay in effect for the OriginEndpoint.
     */
    readonly timeDelaySeconds: pulumi.Output<number | undefined>;
    /**
     * The URL of the packaged OriginEndpoint for consumption.
     */
    readonly url: pulumi.Output<string>;
    /**
     * A list of source IP CIDR blocks that will be allowed to access the OriginEndpoint.
     */
    readonly whitelist: pulumi.Output<string[] | undefined>;
    /**
     * Create a OriginEndpoint resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: OriginEndpointArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a OriginEndpoint resource.
 */
export interface OriginEndpointArgs {
    /**
     * Parameters for CDN authorization.
     */
    authorization?: pulumi.Input<inputs.mediapackage.OriginEndpointAuthorizationArgs>;
    /**
     * The ID of the OriginEndpoint.
     */
    awsId: pulumi.Input<string>;
    /**
     * The ID of the Channel the OriginEndpoint is associated with.
     */
    channelId: pulumi.Input<string>;
    /**
     * Parameters for Common Media Application Format (CMAF) packaging.
     */
    cmafPackage?: pulumi.Input<inputs.mediapackage.OriginEndpointCmafPackageArgs>;
    /**
     * Parameters for DASH packaging.
     */
    dashPackage?: pulumi.Input<inputs.mediapackage.OriginEndpointDashPackageArgs>;
    /**
     * A short text description of the OriginEndpoint.
     */
    description?: pulumi.Input<string>;
    /**
     * Parameters for Apple HLS packaging.
     */
    hlsPackage?: pulumi.Input<inputs.mediapackage.OriginEndpointHlsPackageArgs>;
    /**
     * A short string appended to the end of the OriginEndpoint URL.
     */
    manifestName?: pulumi.Input<string>;
    /**
     * Parameters for Microsoft Smooth Streaming packaging.
     */
    mssPackage?: pulumi.Input<inputs.mediapackage.OriginEndpointMssPackageArgs>;
    /**
     * Control whether origination of video is allowed for this OriginEndpoint. If set to ALLOW, the OriginEndpoint may by requested, pursuant to any other form of access control. If set to DENY, the OriginEndpoint may not be requested. This can be helpful for Live to VOD harvesting, or for temporarily disabling origination
     */
    origination?: pulumi.Input<enums.mediapackage.OriginEndpointOrigination>;
    /**
     * Maximum duration (seconds) of content to retain for startover playback. If not specified, startover playback will be disabled for the OriginEndpoint.
     */
    startoverWindowSeconds?: pulumi.Input<number>;
    /**
     * A collection of tags associated with a resource
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * Amount of delay (seconds) to enforce on the playback of live content. If not specified, there will be no time delay in effect for the OriginEndpoint.
     */
    timeDelaySeconds?: pulumi.Input<number>;
    /**
     * A list of source IP CIDR blocks that will be allowed to access the OriginEndpoint.
     */
    whitelist?: pulumi.Input<pulumi.Input<string>[]>;
}
