import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Amazon OpenSearchService application resource
 */
export declare function getApplication(args: GetApplicationArgs, opts?: pulumi.InvokeOptions): Promise<GetApplicationResult>;
export interface GetApplicationArgs {
    /**
     * The name of the application.
     */
    name: string;
}
export interface GetApplicationResult {
    /**
     * List of application configurations.
     */
    readonly appConfigs?: outputs.opensearchservice.ApplicationAppConfig[];
    /**
     * Amazon Resource Name (ARN) format.
     */
    readonly arn?: string;
    /**
     * List of data sources.
     */
    readonly dataSources?: outputs.opensearchservice.ApplicationDataSource[];
    /**
     * The endpoint for the application.
     */
    readonly endpoint?: string;
    /**
     * Options for configuring IAM Identity Center
     */
    readonly iamIdentityCenterOptions?: outputs.opensearchservice.IamIdentityCenterOptionsProperties;
    /**
     * The identifier of the application.
     */
    readonly id?: string;
    /**
     * An arbitrary set of tags (key-value pairs) for this application.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Amazon OpenSearchService application resource
 */
export declare function getApplicationOutput(args: GetApplicationOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetApplicationResult>;
export interface GetApplicationOutputArgs {
    /**
     * The name of the application.
     */
    name: pulumi.Input<string>;
}
