import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::QBusiness::DataSource Resource Type
 */
export declare function getDataSource(args: GetDataSourceArgs, opts?: pulumi.InvokeOptions): Promise<GetDataSourceResult>;
export interface GetDataSourceArgs {
    /**
     * The identifier of the Amazon Q Business application the data source will be attached to.
     */
    applicationId: string;
    /**
     * The identifier of the Amazon Q Business data source.
     */
    dataSourceId: string;
    /**
     * The identifier of the index the data source is attached to.
     */
    indexId: string;
}
export interface GetDataSourceResult {
    /**
     * Use this property to specify a JSON or YAML schema with configuration properties specific to your data source connector to connect your data source repository to Amazon Q Business . You must use the JSON or YAML schema provided by Amazon Q .
     *
     * The following links have the configuration properties and schemas for AWS CloudFormation for the following connectors:
     *
     * - [Amazon Simple Storage Service](https://docs.aws.amazon.com/amazonq/latest/qbusiness-ug/s3-cfn.html)
     * - [Amazon Q Web Crawler](https://docs.aws.amazon.com/amazonq/latest/qbusiness-ug/web-crawler-cfn.html)
     *
     * Similarly, you can find configuration templates and properties for your specific data source using the following steps:
     *
     * - Navigate to the [Supported connectors](https://docs.aws.amazon.com/amazonq/latest/business-use-dg/connectors-list.html) page in the Amazon Q Business User Guide, and select the data source connector of your choice.
     * - Then, from that specific data source connector's page, choose the topic containing *Using AWS CloudFormation* to find the schemas for your data source connector, including configuration parameter descriptions and examples.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::QBusiness::DataSource` for more information about the expected schema for this property.
     */
    readonly configuration?: any;
    /**
     * The Unix timestamp when the Amazon Q Business data source was created.
     */
    readonly createdAt?: string;
    /**
     * The Amazon Resource Name (ARN) of a data source in an Amazon Q Business application.
     */
    readonly dataSourceArn?: string;
    /**
     * The identifier of the Amazon Q Business data source.
     */
    readonly dataSourceId?: string;
    /**
     * A description for the data source connector.
     */
    readonly description?: string;
    /**
     * The name of the Amazon Q Business data source.
     */
    readonly displayName?: string;
    /**
     * Provides the configuration information for altering document metadata and content during the document ingestion process.
     *
     * For more information, see [Custom document enrichment](https://docs.aws.amazon.com/amazonq/latest/business-use-dg/custom-document-enrichment.html) .
     */
    readonly documentEnrichmentConfiguration?: outputs.qbusiness.DataSourceDocumentEnrichmentConfiguration;
    /**
     * The configuration for extracting information from media in documents.
     */
    readonly mediaExtractionConfiguration?: outputs.qbusiness.DataSourceMediaExtractionConfiguration;
    /**
     * The Amazon Resource Name (ARN) of an IAM role with permission to access the data source and required resources.
     */
    readonly roleArn?: string;
    /**
     * The status of the Amazon Q Business data source.
     */
    readonly status?: enums.qbusiness.DataSourceStatus;
    /**
     * Sets the frequency for Amazon Q Business to check the documents in your data source repository and update your index. If you don't set a schedule, Amazon Q Business won't periodically update the index.
     *
     * Specify a `cron-` format schedule string or an empty string to indicate that the index is updated on demand. You can't specify the `Schedule` parameter when the `Type` parameter is set to `CUSTOM` . If you do, you receive a `ValidationException` exception.
     */
    readonly syncSchedule?: string;
    /**
     * A list of key-value pairs that identify or categorize the data source connector. You can also use tags to help control access to the data source connector. Tag keys and values can consist of Unicode letters, digits, white space, and any of the following symbols: _ . : / = + - @.
     */
    readonly tags?: outputs.Tag[];
    /**
     * The type of the Amazon Q Business data source.
     */
    readonly type?: string;
    /**
     * The Unix timestamp when the Amazon Q Business data source was last updated.
     */
    readonly updatedAt?: string;
    /**
     * Configuration information for an Amazon VPC (Virtual Private Cloud) to connect to your data source. For more information, see [Using Amazon VPC with Amazon Q Business connectors](https://docs.aws.amazon.com/amazonq/latest/business-use-dg/connector-vpc.html) .
     */
    readonly vpcConfiguration?: outputs.qbusiness.DataSourceVpcConfiguration;
}
/**
 * Definition of AWS::QBusiness::DataSource Resource Type
 */
export declare function getDataSourceOutput(args: GetDataSourceOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDataSourceResult>;
export interface GetDataSourceOutputArgs {
    /**
     * The identifier of the Amazon Q Business application the data source will be attached to.
     */
    applicationId: pulumi.Input<string>;
    /**
     * The identifier of the Amazon Q Business data source.
     */
    dataSourceId: pulumi.Input<string>;
    /**
     * The identifier of the index the data source is attached to.
     */
    indexId: pulumi.Input<string>;
}
