import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Creates a custom DB engine version (CEV).
 */
export declare function getCustomDbEngineVersion(args: GetCustomDbEngineVersionArgs, opts?: pulumi.InvokeOptions): Promise<GetCustomDbEngineVersionResult>;
export interface GetCustomDbEngineVersionArgs {
    /**
     * The database engine to use for your custom engine version (CEV).
     *  Valid values:
     *   +   ``custom-oracle-ee``
     *   +   ``custom-oracle-ee-cdb``
     */
    engine: string;
    /**
     * The name of your CEV. The name format is ``major version.customized_string``. For example, a valid CEV name is ``19.my_cev1``. This setting is required for RDS Custom for Oracle, but optional for Amazon RDS. The combination of ``Engine`` and ``EngineVersion`` is unique per customer per Region.
     *   *Constraints:* Minimum length is 1. Maximum length is 60.
     *   *Pattern:* ``^[a-z0-9_.-]{1,60$``}
     */
    engineVersion: string;
}
export interface GetCustomDbEngineVersionResult {
    /**
     * The ARN of the custom engine version.
     */
    readonly dbEngineVersionArn?: string;
    /**
     * An optional description of your CEV.
     */
    readonly description?: string;
    /**
     * A value that indicates the status of a custom engine version (CEV).
     */
    readonly status?: enums.rds.CustomDbEngineVersionStatus;
    /**
     * A list of tags. For more information, see [Tagging Amazon RDS Resources](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_Tagging.html) in the *Amazon RDS User Guide.*
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Creates a custom DB engine version (CEV).
 */
export declare function getCustomDbEngineVersionOutput(args: GetCustomDbEngineVersionOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetCustomDbEngineVersionResult>;
export interface GetCustomDbEngineVersionOutputArgs {
    /**
     * The database engine to use for your custom engine version (CEV).
     *  Valid values:
     *   +   ``custom-oracle-ee``
     *   +   ``custom-oracle-ee-cdb``
     */
    engine: pulumi.Input<string>;
    /**
     * The name of your CEV. The name format is ``major version.customized_string``. For example, a valid CEV name is ``19.my_cev1``. This setting is required for RDS Custom for Oracle, but optional for Amazon RDS. The combination of ``Engine`` and ``EngineVersion`` is unique per customer per Region.
     *   *Constraints:* Minimum length is 1. Maximum length is 60.
     *   *Pattern:* ``^[a-z0-9_.-]{1,60$``}
     */
    engineVersion: pulumi.Input<string>;
}
