import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * A zero-ETL integration with Amazon Redshift.
 */
export declare class Integration extends pulumi.CustomResource {
    /**
     * Get an existing Integration resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Integration;
    /**
     * Returns true if the given object is an instance of Integration.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Integration;
    /**
     * An optional set of non-secret key–value pairs that contains additional contextual information about the data. For more information, see [Encryption context](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#encrypt_context) in the *Key Management Service Developer Guide*.
     *  You can only include this parameter if you specify the ``KMSKeyId`` parameter.
     */
    readonly additionalEncryptionContext: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * The time when the integration was created, in Universal Coordinated Time (UTC).
     */
    readonly createTime: pulumi.Output<string>;
    /**
     * Data filters for the integration. These filters determine which tables from the source database are sent to the target Amazon Redshift data warehouse.
     */
    readonly dataFilter: pulumi.Output<string | undefined>;
    /**
     * A description of the integration.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The ARN of the integration.
     */
    readonly integrationArn: pulumi.Output<string>;
    /**
     * The name of the integration.
     */
    readonly integrationName: pulumi.Output<string | undefined>;
    /**
     * The AWS Key Management System (AWS KMS) key identifier for the key to use to encrypt the integration. If you don't specify an encryption key, RDS uses a default AWS owned key.
     */
    readonly kmsKeyId: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the database to use as the source for replication.
     */
    readonly sourceArn: pulumi.Output<string>;
    /**
     * A list of tags. For more information, see [Tagging Amazon RDS Resources](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_Tagging.html) in the *Amazon RDS User Guide.*.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The ARN of the Redshift data warehouse to use as the target for replication.
     */
    readonly targetArn: pulumi.Output<string>;
    /**
     * Create a Integration resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: IntegrationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Integration resource.
 */
export interface IntegrationArgs {
    /**
     * An optional set of non-secret key–value pairs that contains additional contextual information about the data. For more information, see [Encryption context](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#encrypt_context) in the *Key Management Service Developer Guide*.
     *  You can only include this parameter if you specify the ``KMSKeyId`` parameter.
     */
    additionalEncryptionContext?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * Data filters for the integration. These filters determine which tables from the source database are sent to the target Amazon Redshift data warehouse.
     */
    dataFilter?: pulumi.Input<string>;
    /**
     * A description of the integration.
     */
    description?: pulumi.Input<string>;
    /**
     * The name of the integration.
     */
    integrationName?: pulumi.Input<string>;
    /**
     * The AWS Key Management System (AWS KMS) key identifier for the key to use to encrypt the integration. If you don't specify an encryption key, RDS uses a default AWS owned key.
     */
    kmsKeyId?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) of the database to use as the source for replication.
     */
    sourceArn: pulumi.Input<string>;
    /**
     * A list of tags. For more information, see [Tagging Amazon RDS Resources](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_Tagging.html) in the *Amazon RDS User Guide.*.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The ARN of the Redshift data warehouse to use as the target for replication.
     */
    targetArn: pulumi.Input<string>;
}
