import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::RefactorSpaces::Route Resource Type
 */
export declare class Route extends pulumi.CustomResource {
    /**
     * Get an existing Route resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Route;
    /**
     * Returns true if the given object is an instance of Route.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Route;
    /**
     * The unique identifier of the application.
     */
    readonly applicationIdentifier: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the route.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Configuration for the default route type.
     */
    readonly defaultRoute: pulumi.Output<outputs.refactorspaces.RouteDefaultRouteInput | undefined>;
    /**
     * The unique identifier of the environment.
     */
    readonly environmentIdentifier: pulumi.Output<string>;
    /**
     * A mapping of Amazon API Gateway path resources to resource IDs.
     */
    readonly pathResourceToId: pulumi.Output<string>;
    /**
     * The unique identifier of the route.
     */
    readonly routeIdentifier: pulumi.Output<string>;
    /**
     * The route type of the route.
     */
    readonly routeType: pulumi.Output<enums.refactorspaces.RouteType>;
    /**
     * The unique identifier of the service.
     */
    readonly serviceIdentifier: pulumi.Output<string>;
    /**
     * Metadata that you can assign to help organize the frameworks that you create. Each tag is a key-value pair.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The configuration for the URI path route type.
     */
    readonly uriPathRoute: pulumi.Output<outputs.refactorspaces.RouteUriPathRouteInput | undefined>;
    /**
     * Create a Route resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: RouteArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Route resource.
 */
export interface RouteArgs {
    /**
     * The unique identifier of the application.
     */
    applicationIdentifier: pulumi.Input<string>;
    /**
     * Configuration for the default route type.
     */
    defaultRoute?: pulumi.Input<inputs.refactorspaces.RouteDefaultRouteInputArgs>;
    /**
     * The unique identifier of the environment.
     */
    environmentIdentifier: pulumi.Input<string>;
    /**
     * The route type of the route.
     */
    routeType: pulumi.Input<enums.refactorspaces.RouteType>;
    /**
     * The unique identifier of the service.
     */
    serviceIdentifier: pulumi.Input<string>;
    /**
     * Metadata that you can assign to help organize the frameworks that you create. Each tag is a key-value pair.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The configuration for the URI path route type.
     */
    uriPathRoute?: pulumi.Input<inputs.refactorspaces.RouteUriPathRouteInputArgs>;
}
