import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * AWS::RoboMaker::Robot resource creates an AWS RoboMaker Robot.
 */
export declare class Robot extends pulumi.CustomResource {
    /**
     * Get an existing Robot resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Robot;
    /**
     * Returns true if the given object is an instance of Robot.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Robot;
    /**
     * The target architecture of the robot.
     */
    readonly architecture: pulumi.Output<enums.robomaker.RobotArchitecture>;
    /**
     * The Amazon Resource Name (ARN) of the robot.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the fleet.
     */
    readonly fleet: pulumi.Output<string | undefined>;
    /**
     * The Greengrass group id.
     */
    readonly greengrassGroupId: pulumi.Output<string>;
    /**
     * The name for the robot.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * A map that contains tag keys and tag values that are attached to the robot.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a Robot resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: RobotArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Robot resource.
 */
export interface RobotArgs {
    /**
     * The target architecture of the robot.
     */
    architecture: pulumi.Input<enums.robomaker.RobotArchitecture>;
    /**
     * The Amazon Resource Name (ARN) of the fleet.
     */
    fleet?: pulumi.Input<string>;
    /**
     * The Greengrass group id.
     */
    greengrassGroupId: pulumi.Input<string>;
    /**
     * The name for the robot.
     */
    name?: pulumi.Input<string>;
    /**
     * A map that contains tag keys and tag values that are attached to the robot.
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
