import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Transfer::WebApp
 */
export declare class WebApp extends pulumi.CustomResource {
    /**
     * Get an existing WebApp resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): WebApp;
    /**
     * Returns true if the given object is an instance of WebApp.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is WebApp;
    /**
     * The AccessEndpoint is the URL that you provide to your users for them to interact with the Transfer Family web app. You can specify a custom URL or use the default value.
     */
    readonly accessEndpoint: pulumi.Output<string | undefined>;
    /**
     * Specifies the unique Amazon Resource Name (ARN) for the web app.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * You can provide a structure that contains the details for the identity provider to use with your web app.
     *
     * For more details about this parameter, see [Configure your identity provider for Transfer Family web apps](https://docs.aws.amazon.com//transfer/latest/userguide/webapp-identity-center.html) .
     */
    readonly identityProviderDetails: pulumi.Output<outputs.transfer.WebAppIdentityProviderDetails>;
    /**
     * Key-value pairs that can be used to group and search for web apps.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * A structure that contains the customization fields for the web app. You can provide a title, logo, and icon to customize the appearance of your web app.
     */
    readonly webAppCustomization: pulumi.Output<outputs.transfer.WebAppCustomization | undefined>;
    /**
     * A unique identifier for the web app.
     */
    readonly webAppId: pulumi.Output<string>;
    /**
     * A union that contains the value for number of concurrent connections or the user sessions on your web app.
     */
    readonly webAppUnits: pulumi.Output<outputs.transfer.WebAppUnitsProperties | undefined>;
    /**
     * Create a WebApp resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: WebAppArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a WebApp resource.
 */
export interface WebAppArgs {
    /**
     * The AccessEndpoint is the URL that you provide to your users for them to interact with the Transfer Family web app. You can specify a custom URL or use the default value.
     */
    accessEndpoint?: pulumi.Input<string>;
    /**
     * You can provide a structure that contains the details for the identity provider to use with your web app.
     *
     * For more details about this parameter, see [Configure your identity provider for Transfer Family web apps](https://docs.aws.amazon.com//transfer/latest/userguide/webapp-identity-center.html) .
     */
    identityProviderDetails: pulumi.Input<inputs.transfer.WebAppIdentityProviderDetailsArgs>;
    /**
     * Key-value pairs that can be used to group and search for web apps.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * A structure that contains the customization fields for the web app. You can provide a title, logo, and icon to customize the appearance of your web app.
     */
    webAppCustomization?: pulumi.Input<inputs.transfer.WebAppCustomizationArgs>;
    /**
     * A union that contains the value for number of concurrent connections or the user sessions on your web app.
     */
    webAppUnits?: pulumi.Input<inputs.transfer.WebAppUnitsPropertiesArgs>;
}
