import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Contains a list of IP addresses. This can be either IPV4 or IPV6. The list will be mutually
 */
export declare function getIpSet(args: GetIpSetArgs, opts?: pulumi.InvokeOptions): Promise<GetIpSetResult>;
export interface GetIpSetArgs {
    /**
     * The ID of the IP set.
     */
    id: string;
    /**
     * The name of the IP set. You cannot change the name of an `IPSet` after you create it.
     */
    name: string;
    /**
     * Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, an AWS AppSync GraphQL API, an Amazon Cognito user pool, an AWS App Runner service, or an AWS Verified Access instance. Valid Values are `CLOUDFRONT` and `REGIONAL` .
     *
     * > For `CLOUDFRONT` , you must create your WAFv2 resources in the US East (N. Virginia) Region, `us-east-1` .
     */
    scope: enums.wafv2.IpSetScope;
}
export interface GetIpSetResult {
    /**
     * List of IPAddresses.
     */
    readonly addresses?: string[];
    /**
     * The Amazon Resource Name (ARN) of the IP set.
     */
    readonly arn?: string;
    /**
     * A description of the IP set that helps with identification.
     */
    readonly description?: string;
    /**
     * The ID of the IP set.
     */
    readonly id?: string;
    /**
     * The version of the IP addresses, either `IPV4` or `IPV6` .
     */
    readonly ipAddressVersion?: enums.wafv2.IpSetIpAddressVersion;
    /**
     * Key:value pairs associated with an AWS resource. The key:value pair can be anything you define. Typically, the tag key represents a category (such as "environment") and the tag value represents a specific value within that category (such as "test," "development," or "production"). You can add up to 50 tags to each AWS resource.
     *
     * > To modify tags on existing resources, use the AWS WAF APIs or command line interface. With AWS CloudFormation , you can only add tags to AWS WAF resources during resource creation.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Contains a list of IP addresses. This can be either IPV4 or IPV6. The list will be mutually
 */
export declare function getIpSetOutput(args: GetIpSetOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetIpSetResult>;
export interface GetIpSetOutputArgs {
    /**
     * The ID of the IP set.
     */
    id: pulumi.Input<string>;
    /**
     * The name of the IP set. You cannot change the name of an `IPSet` after you create it.
     */
    name: pulumi.Input<string>;
    /**
     * Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, an AWS AppSync GraphQL API, an Amazon Cognito user pool, an AWS App Runner service, or an AWS Verified Access instance. Valid Values are `CLOUDFRONT` and `REGIONAL` .
     *
     * > For `CLOUDFRONT` , you must create your WAFv2 resources in the US East (N. Virginia) Region, `us-east-1` .
     */
    scope: pulumi.Input<enums.wafv2.IpSetScope>;
}
